@@ -13,9 +13,10 @@ from typing import (
     Coroutine,
     Any,
     Optional,
-    TYPE_CHECKING, Set
+    TYPE_CHECKING
 )
 
+from .errors import TokenTypeException
 from .httpclient import HTTPClient
 from .state import ConnectionState
 from .ws import SlackWebSocket
@@ -30,8 +31,35 @@ Coro = TypeVar("Coro", bound=Callable[..., Coroutine[Any, Any, Any]])
 _logger = logging.getLogger(__name__)
 
 
+def cancel_task(loop: asyncio.AbstractEventLoop):
+    tasks = {t for t in asyncio.all_tasks(loop=loop) if not t.done()}
+
+    if not tasks:
+        return
+
+    for task in tasks:
+        task.cancel()
+
+    loop.run_until_complete(asyncio.gather(*tasks, return_exceptions=True))
+
+    for task in tasks:
+        if task.cancelled():
+            continue
+
+        if task.exception() is not None:
+            loop.call_exception_handler(
+                {
+                    "message": "Unhandled exception during Client.run shutdown.",
+                    "exception": task.exception(),
+                    "task": task,
+                }
+            )
+            print("is", task)
+
+
 def result_task(loop: asyncio.AbstractEventLoop):
     try:
+        cancel_task(loop=loop)
         loop.run_until_complete(loop.shutdown_asyncgens())
 
     finally:
@@ -51,7 +79,7 @@ class Client:
         The your-self token. It must be start 'xoxp-...'
     bot_token: :class:`str`
         The bot token. It must be start 'xoxb-...'
-    token: :class:`str`
+    token: :class:Optional[`str`]
         App-level token. It is startwith 'xapp-...'
 
     loop: Optional[:class:`asyncio.AbstractEventLoop`]
@@ -64,7 +92,7 @@ class Client:
             self,
             user_token: str,
             bot_token: str,
-            token: str,
+            token: str = None,
 
             loop: Optional[asyncio.AbstractEventLoop] = None,
             **options
@@ -79,6 +107,15 @@ class Client:
         if not all([isinstance(t, str) for t in (user_token, bot_token, token)]):
             raise TypeError("All token must be `str`")
 
+        if not user_token.startswith("xoxp-"):
+            raise TokenTypeException("User token must be start `xoxp-`")
+
+        if not bot_token.startswith("xoxb-"):
+            raise TokenTypeException("Application token must be start `xoxb-`")
+
+        if not token and token.startswith("xapp-"):
+            raise TokenTypeException("Token must be start `xapp-`")
+
         self.ws: SlackWebSocket = None
         self.user_token: str = user_token
         self.bot_token: str = bot_token
@@ -116,7 +153,8 @@ class Client:
             _logger.info("dispatch event %s", method)
 
         except AttributeError as attr:
-            _logger.warning("Attribute Error `%s`", attr)
+            # _logger.warning("Attribute Error `%s`", attr)
+            pass
 
         except Exception as e:
             _logger.error(type(e))
@@ -124,25 +162,20 @@ class Client:
         else:
             self._schedule_event(coro, method, *args, **kwargs)
 
-        if listeners:
-            removed = []
-            for i, (future, condition) in enumerate(listeners):
-                if future.cancelled():
-                    removed.append(i)
-                    continue
-
     def is_closed(self) -> bool:
         """It returns a boolean value.
 
         Returns
         -------
+        :class:`bool`
             The return value is a boolean value.
 
         """
         return self._closed
 
     def event(self, coro: Coro) -> Coro:
-        """`event` is a decorator that takes a coroutine function and sets it as an attribute of the class it's decorating
+        """`event` is a decorator that takes a coroutine function and sets
+         it as an attribute of the class it's decorating.
 
         Parameters
         ----------
@@ -168,6 +201,9 @@ class Client:
         function should not be used. Use :meth:`start` coroutine
         or :meth:`connect` + :meth:`login`.
         Roughly Equivalent to: ::
+
+        .. codeblock:: python
+
             try:
                 loop.run_until_complete(start(*args, **kwargs))
             except KeyboardInterrupt:
@@ -262,19 +298,6 @@ class Client:
             *args,
             **kwargs
     ) -> asyncio.Task:
-        """
-
-        Parameters
-        ----------
-        coro : :class:`Callable[..., Coroutine[Any, Any, Any]]`
-        event_name : :class:`str`
-        args : :class:`Any`
-        kwargs : :class:`Any`
-
-        Returns
-        -------
-            asyncio.Task
-        """
         wrapped = self._run_event(coro, event_name, *args, **kwargs)
         # Schedules the task
         return asyncio.create_task(wrapped, name=f"with: {event_name}")
