@@ -56,29 +56,32 @@ class Message:
         self.content = data.get("text", "")
         self.created_at: datetime = datetime.fromtimestamp(float(self.id))
 
+    def __repr__(self):
+        return f"<{self.__class__.__name__} id={self.id} channel_id={self.channel_id}>"
+
     @property
     def channel(self) -> Channel:
         """Message channel data.
 
         Returns
         -------
-        :class:`~Channel`
+        :class:`Channel`
             Message channel.
 
         """
         return self.state.channels[self.channel_id]
 
     @property
-    def author(self) -> Member:
+    def author(self) -> Optional[Member]:
         """Message author.
 
         Returns
         -------
-        :class:`~Member`
+        Optional[:class:`Member`]
             Message author.
 
         """
-        return self.state.members[self.user]
+        return self.state.members.get(self.user)
 
     @property
     def team(self) -> Team:
@@ -96,12 +99,12 @@ class Message:
         """
         param = {
             "channel": self.channel_id,
-            "ts": self.id,
+            "ts": self.id
         }
-        self.state.http.delete_message(
+        await self.state.http.delete_message(
             Route(
                 "DELETE",
-                "message.delete",
+                "chat.delete",
                 self.state.http.bot_token
             ),
             param
@@ -135,16 +138,16 @@ class PreviousMessage:
     """
     Attributes
     ----------
-    text: str
+    text: :class:`str`
         Message
 
-    user: Member
+    user: :class:`Member`
         Sent by
 
-    team: Team
+    team: :class:`Team`
         Sent team
 
-    ts: datetime
+    ts: :class:`datetime`
         timestamp
     """
     def __init__(self, state: ConnectionState, data: PreviousMessagePayload):
