@@ -102,6 +102,7 @@ class ConnectionState:
         teams: Dict[str, Any] = await self.http.request(
             Route("GET", "auth.teams.list", self.http.bot_token)
         )
+        await asyncio.sleep(.5)
         for team in teams["teams"]:
             team_id = team["id"]
             info = await self.http.request(
@@ -111,7 +112,8 @@ class ConnectionState:
                 }
             )
             self.teams[team_id] = Team(state=self, data=info["team"])
-        await asyncio.sleep(0.2)
+            await asyncio.sleep(.2)
+        await asyncio.sleep(0.5)
         for team in teams["teams"]:
             team_id = team["id"]
             channels: Dict[str, Any] = await self.http.request(
@@ -121,6 +123,7 @@ class ConnectionState:
                 }
             )
             self.channels = {ch["id"]: Channel(state=self, data=ch) for ch in channels["channels"]}
+            await asyncio.sleep(0.2)
 
         await asyncio.sleep(0.5)
         members: Dict[str, Any] = await self.http.request(
@@ -162,6 +165,7 @@ class ConnectionState:
         ch_data = event['channel']
         channel = Channel(state=self, data=ch_data)
         self.all_events.add("on_channel_create")
+        self.channels[channel.id] = channel
         self.dispatch("channel_create", channel)
 
     def parse_channel_deleted(self, payload: Dict[str, Any]) -> None:
@@ -175,6 +179,7 @@ class ConnectionState:
         """
         event = payload['event']
         channel = DeletedChannel(state=self, data=event)
+        del self.channels[channel.channel_id]
         self.all_events.add("on_channel_delete")
         self.dispatch("channel_delete", channel)
 
